import sys
import salome

salome.salome_init()
theStudy = salome.myStudy

import salome_notebook
notebook = salome_notebook.notebook
sys.path.insert( 0, r'/cae_sg500/caexample/caelinux/coque_3d/stress2')


###
### GEOM component
###

import GEOM
import geompy
import math
import SALOMEDS


import inspect
import os  

#set current path and brep filename
cfilename =  inspect.getfile(inspect.currentframe())
cdir = os.path.dirname(cfilename)
BrepFileName = 'plane4holes.brep'
PathFileName = os.path.join(cdir,BrepFileName)


geompy.init_geom(theStudy)
plane4holes_brep_1 = geompy.ImportBREP(PathFileName)
[geomObj_1] = geompy.ExtractShapes(plane4holes_brep_1, geompy.ShapeType["COMPOUND"], True)
[Lmx,C1,C2,Lmy,Lpy,C3,C4,Lpx] = geompy.ExtractShapes(plane4holes_brep_1, geompy.ShapeType["EDGE"], True)
Plane = geompy.MakeFaceWires([Lmx, C1, C2, Lmy, Lpy, C3, C4, Lpx], 1)
listSubShapeIDs = geompy.SubShapeAllIDs(Plane, geompy.ShapeType["EDGE"])
listSubShapeIDs = geompy.SubShapeAllIDs(Plane, geompy.ShapeType["EDGE"])
listSubShapeIDs = geompy.SubShapeAllIDs(Plane, geompy.ShapeType["FACE"])
Lmx = geompy.CreateGroup(Plane, geompy.ShapeType["EDGE"])
geompy.UnionIDs(Lmx, [3])
Lpx = geompy.CreateGroup(Plane, geompy.ShapeType["EDGE"])
geompy.UnionIDs(Lpx, [8])
shell = geompy.CreateGroup(Plane, geompy.ShapeType["FACE"])
geompy.UnionIDs(shell, [1])
geompy.addToStudy( plane4holes_brep_1, 'plane4holes.brep_1' )
#geompy.addToStudyInFather( plane4holes_brep_1, Lmx, 'Lmx' )
#geompy.addToStudyInFather( plane4holes_brep_1, C1, 'C1' )
#geompy.addToStudyInFather( plane4holes_brep_1, C2, 'C2' )
#geompy.addToStudyInFather( plane4holes_brep_1, Lmy, 'Lmy' )
#geompy.addToStudyInFather( plane4holes_brep_1, Lpy, 'Lpy' )
#geompy.addToStudyInFather( plane4holes_brep_1, C3, 'C3' )
#geompy.addToStudyInFather( plane4holes_brep_1, C4, 'C4' )
#geompy.addToStudyInFather( plane4holes_brep_1, Lpx, 'Lpx' )
geompy.addToStudy( Plane, 'Plane' )
geompy.addToStudyInFather( Plane, Lmx, 'Lmx' )
geompy.addToStudyInFather( Plane, Lpx, 'Lpx' )
geompy.addToStudyInFather( Plane, shell, 'shell' )




import smesh, SMESH, SALOMEDS

smesh.SetCurrentStudy(theStudy)
import StdMeshers
import NETGENPlugin

Mesh = smesh.Mesh(Plane)
MaxLength = smesh.CreateHypothesis('MaxLength')
MaxLength.SetLength( 12 )
QuadraticMesh = smesh.CreateHypothesis('QuadraticMesh')
#Regular_1D = Mesh.Segment()
NETGEN_2D = Mesh.Triangle(algo=smesh.NETGEN_1D2D)
NETGEN_2D_Parameters = NETGEN_2D.Parameters()
NETGEN_2D_Parameters.SetSecondOrder( 1 )
NETGEN_2D_Parameters.SetOptimize( 1 )
NETGEN_2D_Parameters.SetFineness( 2 )
NETGEN_2D_Parameters.SetQuadAllowed( 0 )
NETGEN_2D_Parameters.SetMaxSize( 2 )
NETGEN_2D_Parameters.SetMinSize( 2 )
isDone = Mesh.Compute()
Lmx = Mesh.GroupOnGeom(Lmx,'Group',SMESH.EDGE)
Lpx = Mesh.GroupOnGeom(Lpx,'Group',SMESH.EDGE)
shell = Mesh.GroupOnGeom(shell,'Group',SMESH.FACE)
Lmx.SetName( 'Lmx' )
Lpx.SetName( 'Lpx' )
shell.SetName( 'shell' )
smesh.SetName(Mesh, 'Mesh')
NETGEN_2D = Mesh.Triangle(algo=smesh.NETGEN_1D2D)
NETGEN_2D_Parameters.SetMaxSize( 2 )
NETGEN_2D_Parameters.SetSecondOrder( 1 )
NETGEN_2D_Parameters.SetOptimize( 1 )
NETGEN_2D_Parameters.SetFineness( 2 )
NETGEN_2D_Parameters.SetMinSize( 2 )
NETGEN_2D_Parameters.SetQuadAllowed( 0 )
isDone = Mesh.Compute()

## set object names
smesh.SetName(Mesh.GetMesh(),'Mesh')
smesh.SetName(MaxLength, 'MaxLength')
smesh.SetName(QuadraticMesh, 'QuadraticMesh')
smesh.SetName(NETGEN_2D.GetAlgorithm(), 'NETGEN_2D')
smesh.SetName(Lmx, 'Lmx')
smesh.SetName(Lpx, 'Lpx')
smesh.SetName(shell, 'shell')

cfilename =  inspect.getfile(inspect.currentframe())
cdir = os.path.dirname(cfilename)
MeshFileName = 'Mshell.med'
PathFileName = os.path.join(cdir,MeshFileName)
Mesh.ExportMED(PathFileName, 0, SMESH.MED_V2_2,1)

if salome.sg.hasDesktop():
  salome.sg.updateObjBrowser(1)

